@@ -154,7 +154,7 @@ Your Open edX platform is ready and can be accessed at the following urls:
 @click.option(
     "--from",
     "from_release",
-    type=click.Choice(["ironwood", "juniper", "koa", "lilac"]),
+    type=click.Choice(["ironwood", "juniper", "koa", "lilac", "maple"]),
 )
 @click.pass_context
 def upgrade(context: click.Context, from_release: t.Optional[str]) -> None:
